@@ -157,7 +157,7 @@ class DataStorage():
                 pandas.DataFrame
         """
         if not black_list:
-            black_list = ['os', 'git', 'datetime', 'definitions_config', 'get_git_details', 'create_ts', 'slash_to_dash', 'dictionary_from_module', 'setup_default_session']
+            black_list = ['os', 'git', 'datetime', 'Session', 'session', 'get_git_details', 'create_ts', 'slash_to_dash', 'dictionary_from_module', 'setup_default_session']
         columns_names = [item for item in dir(config) if not item.startswith("__") and not item in (black_list)]
         return self.create_dataframe(config, columns_names)
     def save_test(self, test, columns=['target', 'identifier'], s3_url=None):
